@@ -280,7 +280,7 @@ class Crp:
         # Calculate the target value
         target_value = self.getTargetValues(train_data,target_frame)
         # Calculate features
-        df = self.getFeaturesMatrix(train_data,original_dataset,lag,items_dataset,customer_name,train_window,sq_pass)
+        df = self.getFeaturesMatrix(train_data,df,lag,items_dataset,customer_name,train_window,sq_pass)
         
         # Merge feature sets
         # data = self.getMergedDF(df,'customerid')
@@ -322,7 +322,7 @@ class Crp:
     
         df= self.getCleanData(original_dataset)
 
-        
+
         output.append(self.prepareDF(df,dateFlag_sep,date_flag_min,lag,items_dataset,customer_name,train_window,sq_pass))
         print(dateFlag_sep,date_flag_min)
         # Repeat the procedure until the bottom limit of the trainFrame reaches the minimum date possible according to the original dataset.
